@@ -115,7 +115,14 @@
 #else
 #  define KICONTHEMES_DEPRECATED_VERSION_5_0(text)
 #endif
+
+#if KICONTHEMES_DEPRECATED_WARNINGS_SINCE >= 0x60500
+#  define KICONTHEMES_DEPRECATED_VERSION_6_5(text) KICONTHEMES_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KICONTHEMES_DEPRECATED_VERSION_6_5(text)
+#endif
 #define KICONTHEMES_DEPRECATED_VERSION_5(minor, text)      KICONTHEMES_DEPRECATED_VERSION_5_##minor(text)
+#define KICONTHEMES_DEPRECATED_VERSION_6(minor, text)      KICONTHEMES_DEPRECATED_VERSION_6_##minor(text)
 #define KICONTHEMES_DEPRECATED_VERSION(major, minor, text) KICONTHEMES_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KICONTHEMES_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KICONTHEMES_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
 #if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
